@@ -53,7 +53,11 @@ def upload_media(api, type_id, path, md5=None, section=None, fname=None,
     token = api.api_client.configuration.api_key['Authorization']
     prefix = api.api_client.configuration.api_key_prefix['Authorization']
 
-    mime,_ = mimetypes.guess_type(fname)
+    mime, _ = mimetypes.guess_type(fname)
+    if mime is None:
+        ext = os.path.splitext(fname)[1].lower()
+        if ext in ['.mts', '.m2ts']:
+            mime = 'video/MP2T'
     response = api.get_media_type(type_id)
     project_id = response.project
 
