@@ -243,7 +243,9 @@ def test_register_algorithm(host: str, token: str, project: int, algo_project: i
         description='test_description',
         manifest=manifest_url,
         cluster=None,
-        files_per_job=1)
+        files_per_job=1,
+        categories=['category1, category2, category3'],
+        parameters=[{'name':'param1', 'value':'bool'}])
 
     response = tator_api.register_algorithm(project=project, algorithm_spec=spec)
 
@@ -265,7 +267,9 @@ def test_register_algorithm(host: str, token: str, project: int, algo_project: i
         user=user_id,
         description='new_test_description',
         manifest='coolfile.yaml',
-        files_per_job=2)
+        files_per_job=2,
+        categories=['categoryA, categoryB'],
+        parameters=[{'name': 'paramA', 'value':'int'}, {'name':'paramB', 'value':'string'}])
     response = tator_api.update_algorithm(id=algorithm_id, algorithm_spec=spec)
     algorithm_info = tator_api.get_algorithm(id=algorithm_id)
     spec.id = algorithm_id
@@ -365,9 +369,7 @@ def test_register_algorithm_with_missing_fields(
     spec = tator.models.Algorithm(
         project=project,
         user=user_id,
-        description=DESCRIPTION,
         manifest=manifest_url,
-        cluster=CLUSTER,
         files_per_job=FILES_PER_JOB)
 
     with pytest.raises(tator.openapi.tator_openapi.exceptions.ApiException):
@@ -377,22 +379,7 @@ def test_register_algorithm_with_missing_fields(
     spec = tator.models.Algorithm(
         name=NAME,
         project=project,
-        description=DESCRIPTION,
         manifest=manifest_url,
-        cluster=CLUSTER,
-        files_per_job=FILES_PER_JOB)
-
-    with pytest.raises(tator.openapi.tator_openapi.exceptions.ApiException):
-        tator_api.register_algorithm(project=project, algorithm_spec=spec)
-
-    # Missing description field
-    spec = tator.models.Algorithm(
-        name=NAME,
-        project=project,
-        user=user_id,
-        description=DESCRIPTION,
-        manifest=manifest_url,
-        cluster=CLUSTER,
         files_per_job=FILES_PER_JOB)
 
     with pytest.raises(tator.openapi.tator_openapi.exceptions.ApiException):
@@ -403,8 +390,6 @@ def test_register_algorithm_with_missing_fields(
         name=NAME,
         project=project,
         user=user_id,
-        description=DESCRIPTION,
-        cluster=CLUSTER,
         files_per_job=FILES_PER_JOB)
 
     with pytest.raises(tator.openapi.tator_openapi.exceptions.ApiException):
@@ -415,9 +400,7 @@ def test_register_algorithm_with_missing_fields(
         name=NAME,
         project=project,
         user=user_id,
-        description=DESCRIPTION,
-        manifest=manifest_url,
-        cluster=CLUSTER)
+        manifest=manifest_url)
 
     with pytest.raises(tator.openapi.tator_openapi.exceptions.ApiException):
         tator_api.register_algorithm(project=project, algorithm_spec=spec)
